/*!
 * @file main.c
 * @brief Step Down 5 Click example
 *
 * # Description
 * This library contains API for the Step Down 5 Click driver.
 * This driver provides the functions to set the output voltage treshold.
 *
 * The demo application is composed of two sections :
 *
 * ## Application Init
 * Initialization of I2C module and log UART.
 * After driver initialization, default settings sets output voltage to 0.6 V.
 *
 * ## Application Task
 * This example demonstrates the use of the Step Down 5 Click board™.
 * Reading user's input from UART Terminal and using it to setup output voltage level.
 * Results are being sent to the UART Terminal, where you can track their changes.
 *
 * @author Stefan Ilic
 *
 */

#include "board.h"
#include "log.h"
#include "stepdown5.h"

static stepdown5_t stepdown5;
static log_t logger;

static void display_selection ( void ) 
{
    log_printf( &logger, "  To select output voltage  \r\n" );
    log_printf( &logger, "  Send one of the numbers:  \r\n" );
    log_printf( &logger, "- - - - - - - - - - - - - - \r\n" );
    log_printf( &logger, " '1' - Output voltage 0.6V  \r\n" );
    log_printf( &logger, " '2' - Output voltage 1.5V  \r\n" );
    log_printf( &logger, " '3' - Output voltage 2.5V  \r\n" );
    log_printf( &logger, " '4' - Output voltage 3.3V  \r\n" );
    log_printf( &logger, "--------------------------- \r\n" );
}

void application_init ( void ) 
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    stepdown5_cfg_t stepdown5_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    stepdown5_cfg_setup( &stepdown5_cfg );
    STEPDOWN5_MAP_MIKROBUS( stepdown5_cfg, MIKROBUS_1 );
    if ( I2C_MASTER_ERROR == stepdown5_init( &stepdown5, &stepdown5_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }
    
    if ( STEPDOWN5_ERROR == stepdown5_default_cfg ( &stepdown5 ) )
    {
        log_error( &logger, " Default configuration." );
        for ( ; ; );
    }
    
    log_info( &logger, " Application Task " );
    
    display_selection( );
}

void application_task ( void ) 
{
static char index;
    
    if ( STEPDOWN5_ERROR != log_read( &logger, &index, 1 ) ) 
    {
        if ( ( index >= '1' ) && ( index <= '4' ) ) 
        {
            stepdown5_set_output ( &stepdown5, index - 48 );
            log_printf( &logger, "  >>> Selected mode %d     \r\n", index - 48 );
            log_printf( &logger, "---------------------------\r\n" );
            Delay_ms( 100 );
        }
        else 
        { 
            log_printf( &logger, "    Data not in range!    \r\n" );
            log_printf( &logger, "---------------------------\r\n" );
            display_selection( );
            Delay_ms( 100 );
        }
    }
}

void main ( void ) 
{
    application_init( );

    for ( ; ; ) 
    {
        application_task( );
    }
}

// ------------------------------------------------------------------------ END
